@@ -12,18 +12,19 @@ import util.misc as misc_utils
 import gvoice
 import handle
 
-import requests
-import contacts
 import aliasing
-import simple_presence
-import presence
+import avatars
 import capabilities
+import contacts
+import presence
+import requests
+import simple_presence
 
 import autogv
 import channel_manager
 
 
-_moduleLogger = logging.getLogger("connection")
+_moduleLogger = logging.getLogger(__name__)
 
 
 class TheOneRingOptions(object):
@@ -50,12 +51,13 @@ class TheOneRingOptions(object):
 
 class TheOneRingConnection(
 	tp.Connection,
-	requests.RequestsMixin,
-	contacts.ContactsMixin,
 	aliasing.AliasingMixin,
-	simple_presence.SimplePresenceMixin,
-	presence.PresenceMixin,
+	avatars.AvatarsMixin,
 	capabilities.CapabilitiesMixin,
+	contacts.ContactsMixin,
+	presence.PresenceMixin,
+	requests.RequestsMixin,
+	simple_presence.SimplePresenceMixin,
 ):
 
 	# overiding base class variable
@@ -108,12 +110,13 @@ class TheOneRingConnection(
 			account,
 			constants._telepathy_implementation_name_
 		)
-		requests.RequestsMixin.__init__(self)
-		contacts.ContactsMixin.__init__(self)
 		aliasing.AliasingMixin.__init__(self)
-		simple_presence.SimplePresenceMixin.__init__(self)
-		presence.PresenceMixin.__init__(self)
+		avatars.AvatarsMixin.__init__(self)
 		capabilities.CapabilitiesMixin.__init__(self)
+		contacts.ContactsMixin.__init__(self)
+		presence.PresenceMixin.__init__(self)
+		requests.RequestsMixin.__init__(self)
+		simple_presence.SimplePresenceMixin.__init__(self)
 
 		self.__manager = weakref.proxy(manager)
 		self.__credentials = (
@@ -214,11 +217,11 @@ class TheOneRingConnection(
 			publishHandle = self.get_handle_by_name(telepathy.HANDLE_TYPE_LIST, "publish")
 			publishProps = self.generate_props(telepathy.CHANNEL_TYPE_CONTACT_LIST, publishHandle, False)
 			self.__channelManager.channel_for_props(publishProps, signal=True)
-		except gvoice.backend.NetworkError, e:
+		except gvoice.backend.NetworkError:
 			_moduleLogger.exception("Connection Failed")
 			self.disconnect(telepathy.CONNECTION_STATUS_REASON_NETWORK_ERROR)
 			return
-		except Exception, e:
+		except Exception:
 			_moduleLogger.exception("Connection Failed")
 			self.disconnect(telepathy.CONNECTION_STATUS_REASON_AUTHENTICATION_FAILED)
 			return
@@ -295,9 +298,10 @@ class TheOneRingConnection(
 			plumber.stop()
 
 		self.__channelManager.close()
+		self.manager.disconnected(self)
+
 		self.session.save(self.__cachePath)
 		self.session.logout()
 		self.session.close()
 
-		self.manager.disconnected(self)
 		_moduleLogger.info("Disconnected")
